<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Service;

use Admin\Entity\AdminUserGroupContent;
use Doctrine\ORM\EntityManager;

class AdminUserGroupContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或编辑管理员组内容
     * @param array $data
     * @param $adminGroupId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditAdminUserGroupContent(array $data, $adminGroupId)
    {
        foreach (ADMIN_LANGUAGE as $language) {
            $adminGroupContent = $this->entityManager->getRepository(AdminUserGroupContent::class)->findOneBy(['adminGroupId' => $adminGroupId, 'languageCode' => $language]);
            if ($adminGroupContent) {
                $adminGroupContent->setAdminGroupName($data['adminGroupName'.$language]);
            } else {
                $adminGroupContent = new AdminUserGroupContent();
                $adminGroupContent->setLanguageCode($language);
                $adminGroupContent->setAdminGroupId($adminGroupId);
                $adminGroupContent->setAdminGroupName($data['adminGroupName'.$language]);

                $this->entityManager->persist($adminGroupContent);
            }

            $this->entityManager->flush();
        }
    }

    /**
     * 删除管理员组内容
     * @param $adminGroupId
     * @return void
     */
    public function deleteAdminUserGroupContent($adminGroupId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(AdminUserGroupContent::class, 'c')->where($qb->expr()->eq('c.adminGroupId', $adminGroupId));
        $qb->getQuery()->execute();
    }
}