<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Service\Translate;

use Laminas\Http\Client;
use Laminas\Json\Json;

class BaiduTranslate
{
    private string $appUrl = 'https://api.fanyi.baidu.com/api/trans/vip/translate';
    private $appId;
    private $secKey;

    public function __construct($translateConfig)
    {
        $this->appId = $translateConfig['appId'];
        $this->secKey= $translateConfig['secKey'];
    }

    /**
     * 百度翻译
     * @param $query
     * @param $from
     * @param $to
     * @return array|string[]|null
     */
    public function cartTranslateBody($query, $from, $to): ?array
    {
        $languageCodeArray = ['zh_CN' => 'zh', 'zh_HK' => 'cht', 'en' => 'en', 'ja' => 'jp', 'ko' => 'kor'];

        $args = array(
            'q'     => $query,
            'appid' => $this->appId,
            'salt'  => rand(10000,99999),
            'from'  => $languageCodeArray[$from],
            'to'    => $languageCodeArray[$to],
        );
        $args['sign']   = md5($this->appId . $query . $args['salt'] . $this->secKey);

        $client = new Client($this->appUrl, [
            'adapter' => 'Laminas\Http\Client\Adapter\Curl',
            'curloptions' => [
                CURLOPT_SSL_VERIFYPEER => false
            ]
        ]);
        $client->setHeaders(['Accept' => 'application/json']);
        $client->setMethod('POST');
        $client->setParameterPost($args);

        try {
            $response = $client->send();
            if ($response->isSuccess()) {
                $array = Json::decode($response->getBody(), Json::TYPE_ARRAY);
                if (isset($array['trans_result'])) return ['state' => 'true', 'content' => $array['trans_result'][0]['dst']];
                if (isset($array['error_code'])) return ['state' => 'false', 'message' => $array['error_code'] . ' ' . $array['error_msg']];
            }
        } catch (\Exception $e) {
            return ['state' => 'false', 'message' => $e->getMessage()];
        }
        return null;
    }
}