<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Repository;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;
use Goods\Entity\GoodsTagGroup;
use Goods\Entity\GoodsTagGroupContent;

class GoodsTagGroupRepository extends EntityRepository
{
    /**
     * 全部标签组
     * @return float|int|mixed|string
     */
    public function findAllTagGroup()
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('g', 'c.tagGroupName')
            ->from(GoodsTagGroup::class, 'g')
            ->leftJoin(GoodsTagGroupContent::class, 'c', Join::WITH, 'g.tagGroupId = c.tagGroupId')
            ->where('c.languageCode = :languageCode')->setParameter('languageCode', SHOP_FONT_LANGUAGE)
            ->orderBy('g.tagGroupSort', 'ASC')
            ->addOrderBy('g.tagGroupId', 'ASC');

        return $query->getQuery()->getResult();
    }

    /*=======================================商城前台=======================================*/

    /**
     * 通过id数组获取标签组
     * @param array $idArray
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function findTagGroupInId(array $idArray, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('t')
            ->addSelect("(SELECT c.tagGroupName FROM ".GoodsTagGroupContent::class." AS c WHERE c.tagGroupId=t.tagGroupId AND c.languageCode='".$languageCode."') AS tagGroupName")
            ->from(GoodsTagGroup::class, 't')
            ->where($query->expr()->in('t.tagGroupId', $idArray))
            ->orderBy('t.tagGroupSort', 'ASC');

        return $query->getQuery()->getResult();
    }
}