<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Service;

use Doctrine\ORM\EntityManager;
use Goods\Entity\GoodsAttributeValueContent;

class GoodsAttributeValueContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或者编辑属性值内容
     * @param array $data
     * @param $attributeId
     * @param $valueId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditAttributeValueContent(array $data, $attributeId, $valueId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $valueContent = $this->entityManager->getRepository(GoodsAttributeValueContent::class)->findOneBy(['valueId' => $valueId, 'languageCode' => $language]);
            if ($valueContent) {
                $valueContent->setValueName($data['valueName'.$language]);
            } else {
                $valueContent = new GoodsAttributeValueContent();
                $valueContent->setValueId($valueId);
                $valueContent->setAttributeId($attributeId);
                $valueContent->setLanguageCode($language);
                $valueContent->setValueName($data['valueName'.$language]);

                $this->entityManager->persist($valueContent);
            }
            $this->entityManager->flush();
        }
    }

    /**
     * 删除属性值内容
     * @param $valueId
     * @return void
     */
    public function deleteAttributeValueContent($valueId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(GoodsAttributeValueContent::class, 'c')->where($qb->expr()->eq('c.valueId', $valueId));
        $qb->getQuery()->execute();
    }

    /**
     * 根据属性id删除属性值内容
     * @param $attributeIdArray
     * @return void
     */
    public function deleteMoreAttributeValueContent($attributeIdArray)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(GoodsAttributeValueContent::class, 'c')->where($qb->expr()->in('c.attributeId', $attributeIdArray));

        $qb->getQuery()->execute();
    }
}