<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Service;

use Doctrine\ORM\EntityManager;
use Goods\Entity\GoodsBrandContent;

class GoodsBrandContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 编辑品牌内容
     * @param array $data
     * @param $brandId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditGoodsBrandContent(array $data, $brandId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $brandContent   = $this->entityManager->getRepository(GoodsBrandContent::class)->findOneBy(['brandId' => $brandId, 'languageCode' => $language]);
            $emptyState     = false;
            if ($brandContent == null) {
                $brandContent = new GoodsBrandContent();
                $brandContent->setBrandId($brandId);
                $brandContent->setLanguageCode($language);
                $emptyState = true;
            }
            $brandContent->setBrandName($data['brandName'.$language]);
            $brandContent->setBrandInfo($data['brandInfo'.$language]);
            $brandContent->setBrandNameExtend($data['brandNameExtend'.$language]);
            $brandContent->setBrandKeywords($data['brandKeywords'.$language]);
            $brandContent->setBrandDescription($data['brandDescription'.$language]);

            if ($emptyState) $this->entityManager->persist($brandContent);

            $this->entityManager->flush();
        }
    }

    /**
     * 删除品牌内容
     * @param $brandId
     * @return void
     */
    public function deleteGoodsBrandContent($brandId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(GoodsBrandContent::class, 'b')->where($qb->expr()->eq('b.brandId', $brandId));
        $qb->getQuery()->execute();
    }
}