<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Operation\Service;

use Doctrine\ORM\EntityManager;
use Operation\Entity\CouponCodeRuleContent;

class CouponCodeRuleContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或者编辑优惠码内容
     * @param array $data
     * @param $couponCodeRuleId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditCouponCodeRuleContent(array $data, $couponCodeRuleId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $ruleContent = $this->entityManager->getRepository(CouponCodeRuleContent::class)->findOneBy(['couponCodeRuleId' => $couponCodeRuleId, 'languageCode' => $language]);
            if ($ruleContent) {
                $ruleContent->setCouponCodeTitle($data['couponCodeTitle'.$language]);
            } else {
                $ruleContent = new CouponCodeRuleContent();
                $ruleContent->setCouponCodeRuleId($couponCodeRuleId);
                $ruleContent->setLanguageCode($language);
                $ruleContent->setCouponCodeTitle($data['couponCodeTitle'.$language]);

                $this->entityManager->persist($ruleContent);
            }
            $this->entityManager->flush();
        }
    }

    /**
     * 删除优惠码内容
     * @param $couponCodeRuleId
     * @return void
     */
    public function deleteCouponCodeRuleContent($couponCodeRuleId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(CouponCodeRuleContent::class, 'c')->where($qb->expr()->eq('c.couponCodeRuleId', $couponCodeRuleId));
        $qb->getQuery()->execute();
    }
}