<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Shop\Plugin;

use Admin\Data\Common;
use Cms\Entity\Cms;
use Cms\Entity\SingleCms;
use Cms\Entity\SingleCmsContent;
use Doctrine\ORM\EntityManager;
use Goods\Entity\GoodsBrand;
use Goods\Entity\GoodsClass;
use Goods\Entity\GoodsSpecTagGoods;
use Laminas\Mvc\Controller\Plugin\AbstractPlugin;
use Laminas\Mvc\I18n\Translator;
use Laminas\Session\Container;
use Operation\Entity\Ad;
use Operation\Entity\AdContent;
use Operation\Entity\AdSlide;

class ShopPartialPlugin extends AbstractPlugin
{
    private $entityManager;
    private $translator;

    public function __construct(
        EntityManager   $entityManager,
        Translator      $translator
    )
    {
        $this->entityManager    = $entityManager;
        $this->translator       = $translator;
    }

    /**
     * 前台首页新闻
     * @param $newsNum
     * @param $templateCode
     * @return array
     */
    public function shopIndexNews($newsNum, $templateCode)
    {
        $newsList = $this->entityManager->getRepository(Cms::class)->findShopIndexNews($this->getController()->shopPlugin()->shopLanguageCode(), $newsNum);
        $newsArray= [];
        if ($newsList == null) return $newsArray;

        foreach ($newsList as $item) {
            $newsArray[] = [
                'id'    => $item[0]->getCmsId(),
                'title' => $item['cmsTitle']
            ];
        }

        return $newsArray;
    }

    /**
     * 前台单页文章调用（多个调用）
     * @param $singleTag
     * @param $templateCode
     * @return array
     */
    public function shopMoreSingleCms($singleTag, $templateCode)
    {
        $singleCmsArray = [];
        $singleCmsList  = $this->entityManager->getRepository(SingleCms::class)->findShopSingleCmsTagTemplateCode($singleTag, $templateCode, $this->getController()->shopPlugin()->shopLanguageCode());
        if($singleCmsList == null) return $singleCmsArray;

        foreach ($singleCmsList as $item) {
            $singleCmsArray[] = [
                'id'    => $item[0]->getSingleCmsId(),
                'title' => $item['singleCmsTitle'],
                'body'  => $item['singleCmsBody']
            ];
        }

        return $singleCmsArray;
    }

    /**
     * 前台单页文章调用（单个调用）
     * @param $singleTag
     * @param $templateCode
     * @return array
     */
    public function shopSingleCms($singleTag, $templateCode)
    {
        $singleCmsInfo = $this->entityManager->getRepository(SingleCms::class)->findOneBy(['singleTag' => $singleTag, 'templateCode' => $templateCode]);
        if($singleCmsInfo == null) return [];

        $singleCmsContent = $this->entityManager->getRepository(SingleCmsContent::class)->findOneBy(['singleCmsId' => $singleCmsInfo->getSingleCmsId(), 'languageCode' => $this->getController()->shopPlugin()->shopLanguageCode()]);

        return [
            'id'    => $singleCmsInfo->getSingleCmsId(),
            'title' => $singleCmsContent == null ? '' : $singleCmsContent->getSingleCmsTitle(),
            'body'  => $singleCmsContent == null ? '' : $singleCmsContent->getSingleCmsBody()
        ];
    }

    /**
     * 前台广告显示
     * @param $adCode
     * @param $templateCode
     * @return mixed
     */
    public function shopAdShow($adCode, $templateCode)
    {
        $adArray= [];
        $adInfo = $this->entityManager->getRepository(Ad::class)->findOneBy(['adPlaceCode' => $adCode, 'templateCode' => $templateCode, 'adState' => 1]);
        if($adInfo == null) return $adArray;
        if((!empty($adInfo->getAdStartTime()) && $adInfo->getAdStartTime() < time()) || (!empty($adInfo->getAdEndTime()) && $adInfo->getAdEndTime() > time())) return $adArray;

        if($adInfo->getAdType() == 'image') {
            $adContent = $this->entityManager->getRepository(AdContent::class)->findOneBy(['adId' => $adInfo->getAdId(), 'languageCode' => $this->getController()->shopPlugin()->shopLanguageCode()]);
            $adArray = [
                'ad_url'    => $adInfo->getAdUrl(),
                'ad_image'  => $adInfo->getAdBody(),
                'ad_words'  => $adContent == null ? '' : $adContent->getAdWords()
            ];
        } else {
            $slideImage = $this->entityManager->getRepository(AdSlide::class)->findAdSlide($adInfo->getAdId(), $this->getController()->shopPlugin()->shopLanguageCode());
            if($slideImage) foreach ($slideImage as $imageValue) {
                $adArray[] = [
                    'ad_url'    => $imageValue[0]->getAdSlideUrl(),
                    'ad_image'  => $imageValue[0]->getAdSlideImage(),
                    'ad_words'  => $imageValue['adWords'] ?? ''
                ];
            }
        }

        return $adArray;
    }

    /**
     * 前台商品显示
     * @param $goodsTag
     * @param $templateCode
     * @return mixed
     */
    public function shopGoodsShow($goodsTag, $templateCode)
    {
        $goodsList = $this->entityManager->getRepository(GoodsSpecTagGoods::class)->findSpecTagGoodsByTagAndTemplate($goodsTag, $templateCode, $this->getController()->shopPlugin()->getUserLoginData('user_group_id'), $this->getController()->shopPlugin()->shopLanguageCode());

        return $goodsList;
    }

    /**
     * 前台品牌显示
     * @return array|GoodsBrand[]|object[]
     */
    public function shopBrandShow()
    {
        return $this->entityManager->getRepository(GoodsBrand::class)->findBy([], ['brandSort' => 'ASC']);

    }

    /**
     * 获取两级的商品分类
     * @return array
     */
    public function secGoodsClass()
    {
        //商品分类
        $goodsClass = $this->entityManager->getRepository(GoodsClass::class)->findShopAllClass($this->getController()->shopPlugin()->shopLanguageCode());
        $classList  = Common::classOptions($goodsClass, 0, 'getClassTopId', 'getClassId', 2);

        $classArray     = [];
        $subClassArray  = [];
        if($classList) foreach ($classList as $classValue) {
            if($classValue[0]->getClassTopId() == 0) $classArray[] = $classValue;
            else $subClassArray[$classValue[0]->getClassTopId()][] = $classValue;
        }

        return ['classArray' => $classArray, 'subClassArray' => $subClassArray];
    }

    /**
     * 获取下级商品分类
     * @param $classTopId
     * @return array|GoodsClass[]|object[]
     */
    public function goodsSubClass($classTopId)
    {
        return $this->entityManager->getRepository(GoodsClass::class)->findShopClassSub($classTopId, $this->getController()->shopPlugin()->shopLanguageCode());
    }
}